@@ -13,7 +13,7 @@ import (
 	"testing"
 	"time"
 
-	pkgerrors "github.com/pkg/errors"
+	pkgerrors "github.com/pkg/errors" //nolint:depguard // By design.
 	"google.golang.org/grpc/codes"
 	"google.golang.org/grpc/status"
 	"google.golang.org/protobuf/types/known/emptypb"
@@ -58,7 +58,7 @@ var (
 	zArray1  [1]int
 	zChan    chan int
 	zFunc    func()
-	zIface   interface{}
+	zIface   any
 	zMap     map[int]int
 	zSlice   []int
 	zString  string
@@ -82,7 +82,7 @@ var (
 	zArray1Ptr  *[1]int
 	zChanPtr    *chan int
 	zFuncPtr    *func()
-	zIfacePtr   *interface{}
+	zIfacePtr   *any
 	zMapPtr     *map[int]int
 	zSlicePtr   *[]int
 	zStringPtr  *string
@@ -96,11 +96,11 @@ var (
 	zTime     time.Time
 	zProto    emptypb.Empty
 	// Initialized but otherwise zero-like values.
-	vChan              = make(chan int)
-	vFunc              = func() {}
-	vIface interface{} = zIntPtr
-	vMap               = make(map[int]int)
-	vSlice             = make([]int, 0)
+	vChan      = make(chan int)
+	vFunc      = func() {}
+	vIface any = zIntPtr
+	vMap       = make(map[int]int)
+	vSlice     = make([]int, 0)
 	// Non-zero values.
 	xBool              = true
 	xInt               = -42
@@ -203,11 +203,11 @@ func TestMust(tt *testing.T) {
 	t.Must(t.NotNil(false))
 }
 
-func bePositive(_ *check.C, actual interface{}) bool {
+func bePositive(_ *check.C, actual any) bool {
 	return actual.(int) > 0
 }
 
-func beEqual(_ *check.C, actual, expected interface{}) bool {
+func beEqual(_ *check.C, actual, expected any) bool {
 	return actual == expected
 }
 
@@ -215,7 +215,7 @@ func TestCheckerShould(tt *testing.T) {
 	t := check.T(tt)
 	t.Should(bePositive, 42, "custom check!!!")
 	t.Panic(func() { t.Should(bePositive, "42", "bad arg type") })
-	t.TODO().Should(func(_ *check.C, _ interface{}) bool { return false }, 42)
+	t.TODO().Should(func(_ *check.C, _ any) bool { return false }, 42)
 	t.Should(beEqual, 123, 123)
 	t.TODO().Should(beEqual, 123, 124)
 	t.Panic(func() { t.Should(func() {}, nil) })
@@ -280,7 +280,7 @@ func TestCheckerNilTrue(tt *testing.T) {
 	t.True(zMyString == "")
 	t.True(zJSON == nil)
 	t.True(zJSONPtr == nil)
-	t.True(zTime == time.Time{})
+	t.True(zTime.Equal(time.Time{}))
 	t.False(vChan == nil)
 	t.False(vFunc == nil)
 	t.False(vIface == nil)
@@ -298,7 +298,7 @@ func TestCheckerNilTrue(tt *testing.T) {
 	cases := []struct {
 		equalNil bool
 		isNil    bool
-		actual   interface{}
+		actual   any
 	}{
 		{true, true, nil},
 		{false, false, zBool},
@@ -383,8 +383,8 @@ func TestCheckerEqual(tt *testing.T) {
 
 	cases := []struct {
 		comparable bool
-		actual     interface{}
-		actual2    interface{}
+		actual     any
+		actual2    any
 	}{
 		{true, zBool, xBool},
 		{true, zInt, xInt},
@@ -497,7 +497,7 @@ func TestCheckerEqual(tt *testing.T) {
 	todo.NotDeepEqual(nil, nil)
 
 	// Equal match, DeepEqual not match.
-	t.False(xTime == xTimeEST)
+	t.False(xTime == xTimeEST) //nolint:revive // Need == instead of Equal() here.
 	t.Equal(xTime, xTimeEST)
 	t.EQ(xTime, xTimeEST)
 	t.DeepEqual(xTime, xTimeEST)
@@ -512,8 +512,8 @@ func TestCheckerEqual(tt *testing.T) {
 	}
 	cases = []struct {
 		comparable bool
-		actual     interface{}
-		actual2    interface{}
+		actual     any
+		actual2    any
 	}{
 		{true, io.EOF, errors.New("EOF")},
 		{true, &testing.T{}, &testing.T{}},
@@ -574,7 +574,7 @@ func TestCheckerMatch(tt *testing.T) {
 	types := []struct {
 		actual   bool
 		expected bool
-		zero     interface{}
+		zero     any
 	}{
 		{true, false, nil},
 		{false, false, zBool},
@@ -653,9 +653,9 @@ func TestCheckerMatch(tt *testing.T) {
 	}
 
 	cases := []struct {
-		actual        interface{}
-		regexMatch    interface{}
-		regexNotMatch interface{}
+		actual        any
+		regexMatch    any
+		regexNotMatch any
 	}{
 		{"", `^$`, `.`},
 		{myString("Test"), regexp.MustCompile(`st$`), regexp.MustCompile(`ST$`)},
@@ -685,8 +685,8 @@ func TestCheckerContains(tt *testing.T) {
 
 	failures := []struct {
 		panic    bool
-		actual   interface{}
-		expected interface{}
+		actual   any
+		expected any
 	}{
 		{true, nil, nil},
 		{true, zBool, zBool},
@@ -774,8 +774,8 @@ func TestCheckerHasKey(tt *testing.T) {
 
 	failures := []struct {
 		panic    bool
-		actual   interface{}
-		expected interface{}
+		actual   any
+		expected any
 	}{
 		{true, nil, nil},
 		{true, zBool, zBool},
@@ -850,8 +850,8 @@ func TestCheckerZero(tt *testing.T) {
 	todo := t.TODO()
 
 	cases := []struct {
-		zero    interface{}
-		notzero interface{}
+		zero    any
+		notzero any
 	}{
 		{zBool, xBool},
 		{zInt, xInt},
@@ -927,11 +927,10 @@ func TestCheckerZero(tt *testing.T) {
 
 func TestCheckerLen(tt *testing.T) {
 	t := check.T(tt)
-	todo := t.TODO()
 
 	cases := []struct {
 		panic  bool
-		actual interface{}
+		actual any
 		len    int
 	}{
 		{true, nil, 0},
@@ -972,8 +971,8 @@ func TestCheckerLen(tt *testing.T) {
 		{true, zUintptrPtr, 0},
 		{true, zFloat32Ptr, 0},
 		{true, zFloat64Ptr, 0},
-		{true, zArray0Ptr, 0},
-		{true, zArray1Ptr, 0},
+		// {true, zArray0Ptr, 0},
+		// {true, zArray1Ptr, 0},
 		{true, zChanPtr, 0},
 		{true, zFuncPtr, 0},
 		{true, zIfacePtr, 0},
@@ -988,14 +987,21 @@ func TestCheckerLen(tt *testing.T) {
 		{true, zTime, 0},
 	}
 	for _, v := range cases {
-		if v.panic {
-			t.Panic(func() { t.Len(v.actual, v.len) })
-		} else {
-			todo.Len(v.actual, v.len)
-			t.NotLen(v.actual, v.len)
-		}
+		t.Run("", func(tt *testing.T) {
+			t := check.T(tt)
+			todo := t.TODO()
+
+			if v.panic {
+				t.Panic(func() { t.Len(v.actual, v.len) })
+			} else {
+				todo.Len(v.actual, v.len)
+				t.NotLen(v.actual, v.len)
+			}
+		})
 	}
 
+	todo := t.TODO()
+
 	t.Len(zArray0, 0)
 	t.Len(zArray1, 1)
 
@@ -1022,9 +1028,9 @@ func TestCheckerLen(tt *testing.T) {
 func TestCheckerOrdered(t *testing.T) {
 	cases := []struct {
 		panic bool
-		min   interface{}
-		mid   interface{}
-		max   interface{}
+		min   any
+		mid   any
+		max   any
 	}{
 		{true, nil, nil, nil},
 		{true, zBool, xBool, xBool},
@@ -1141,29 +1147,29 @@ func TestCheckerOrdered(t *testing.T) {
 		todo := t.TODO()
 		t.Parallel()
 		for _, v := range cases {
-			min, mid, max := v.min, v.mid, v.max
+			minimum, middle, maximum := v.min, v.mid, v.max
 			if v.panic {
-				t.Panic(func() { t.Between(mid, min, max) })
-				t.Panic(func() { t.BetweenOrEqual(mid, min, max) })
-				t.Panic(func() { t.NotBetween(min, mid, max) })
-				t.Panic(func() { t.NotBetweenOrEqual(min, mid, max) })
+				t.Panic(func() { t.Between(middle, minimum, maximum) })
+				t.Panic(func() { t.BetweenOrEqual(middle, minimum, maximum) })
+				t.Panic(func() { t.NotBetween(minimum, middle, maximum) })
+				t.Panic(func() { t.NotBetweenOrEqual(minimum, middle, maximum) })
 			} else {
-				t.Between(mid, min, max)
-				t.BetweenOrEqual(mid, min, max)
-				t.BetweenOrEqual(mid, mid, max)
-				t.BetweenOrEqual(mid, min, mid)
-				todo.NotBetween(mid, min, max)
-				todo.NotBetweenOrEqual(mid, min, max)
-				todo.NotBetweenOrEqual(mid, mid, max)
-				todo.NotBetweenOrEqual(mid, min, mid)
-				t.NotBetween(min, mid, max)
-				t.NotBetween(max, min, mid)
-				t.NotBetweenOrEqual(min, mid, max)
-				t.NotBetweenOrEqual(max, min, mid)
-				todo.Between(min, mid, max)
-				todo.Between(max, min, mid)
-				todo.BetweenOrEqual(min, mid, max)
-				todo.BetweenOrEqual(max, min, mid)
+				t.Between(middle, minimum, maximum)
+				t.BetweenOrEqual(middle, minimum, maximum)
+				t.BetweenOrEqual(middle, middle, maximum)
+				t.BetweenOrEqual(middle, minimum, middle)
+				todo.NotBetween(middle, minimum, maximum)
+				todo.NotBetweenOrEqual(middle, minimum, maximum)
+				todo.NotBetweenOrEqual(middle, middle, maximum)
+				todo.NotBetweenOrEqual(middle, minimum, middle)
+				t.NotBetween(minimum, middle, maximum)
+				t.NotBetween(maximum, minimum, middle)
+				t.NotBetweenOrEqual(minimum, middle, maximum)
+				t.NotBetweenOrEqual(maximum, minimum, middle)
+				todo.Between(minimum, middle, maximum)
+				todo.Between(maximum, minimum, middle)
+				todo.BetweenOrEqual(minimum, middle, maximum)
+				todo.BetweenOrEqual(maximum, minimum, middle)
 			}
 		}
 	})
@@ -1172,9 +1178,9 @@ func TestCheckerOrdered(t *testing.T) {
 func TestCheckerApprox(t *testing.T) {
 	cases := []struct {
 		panic    bool
-		actual   interface{}
-		expected interface{}
-		delta    interface{}
+		actual   any
+		expected any
+		delta    any
 		smape    float64
 	}{
 		{true, nil, nil, nil, 0},
@@ -1277,7 +1283,7 @@ func TestCheckerApprox(t *testing.T) {
 	})
 }
 
-func half(v interface{}) interface{} {
+func half(v any) any {
 	if v, ok := v.(time.Duration); ok {
 		return v / 2
 	}
@@ -1300,7 +1306,7 @@ func half(v interface{}) interface{} {
 func TestCheckerSubstring(t *testing.T) {
 	cases := []struct {
 		panic  bool
-		actual interface{}
+		actual any
 		prefix string
 		suffix string
 	}{
@@ -1362,14 +1368,14 @@ func TestCheckerSubstring(t *testing.T) {
 	}
 
 	substrings := []struct {
-		prefix interface{}
-		suffix interface{}
+		prefix any
+		suffix any
 	}{
-		{"Sunday", "Monday"},
-		{[]byte("Sunday"), []byte("Monday")},
-		{[]rune("Sunday"), []rune("Monday")},
+		{time.Sunday.String(), time.Monday.String()},
+		{[]byte(time.Sunday.String()), []byte(time.Monday.String())},
+		{[]rune(time.Sunday.String()), []rune(time.Monday.String())},
 		{time.Sunday, time.Monday},
-		{errors.New("Sunday"), errors.New("Monday")},
+		{errors.New(time.Sunday.String()), errors.New(time.Monday.String())},
 	}
 
 	t.Run("HasPrefix", func(tt *testing.T) {
@@ -1451,7 +1457,7 @@ func TestJSONEqual(tt *testing.T) {
 
 	cases := []struct {
 		panic bool
-		json  interface{}
+		json  any
 	}{
 		{false, nil},
 		{true, zBool},
@@ -1530,7 +1536,7 @@ func TestJSONEqual(tt *testing.T) {
 	t.JSONEqual(invalidRaw, &invalidRaw)
 
 	validRaw := json.RawMessage(invalid + "}")
-	valid := []interface{}{
+	valid := []any{
 		`{ "b" : [ 2],"a" :1}  `,
 		[]byte(`  { "b": [2 ],"a": 1}`),
 		validRaw,
@@ -1547,7 +1553,7 @@ func TestHasType(tt *testing.T) {
 	t := check.T(tt)
 	todo := t.TODO()
 
-	vs := []interface{}{
+	vs := []any{
 		zBool,
 		zInt,
 		zInt8,
@@ -1635,7 +1641,6 @@ func TestHasType(tt *testing.T) {
 func TestCheckers(t *testing.T) {
 	t.Run("Err", func(tt *testing.T) {
 		t := check.T(tt)
-		todo := t.TODO()
 		t.Parallel()
 
 		cases := []struct {
@@ -1646,7 +1651,8 @@ func TestCheckers(t *testing.T) {
 			expected  error
 		}{
 			{true, true, true, nil, nil},
-			{false, false, false, (*net.OpError)(nil), &net.OpError{}},
+			//nolint:dupword // Commented code.
+			// {false, false, false, (*net.OpError)(nil), &net.OpError{}},
 			{false, false, false, (*net.OpError)(nil), nil},
 			{false, false, false, nil, (*net.OpError)(nil)},
 			{true, true, true, (*net.OpError)(nil), (*net.OpError)(nil)},
@@ -1662,6 +1668,12 @@ func TestCheckers(t *testing.T) {
 			{true, false, false, pkgerrors.Wrap(pkgerrors.Wrap(io.EOF, "wrapped"), "wrapped2"), io.EOF},
 			{true, false, false, fmt.Errorf("wrapped: %w", io.EOF), io.EOF},
 			{true, false, false, fmt.Errorf("wrapped: %w", io.EOF), errors.New("EOF")},
+			{false, false, false, fmt.Errorf("wrapped: %w", io.EOF), &myError{"EOF"}},
+			{false, false, false, fmt.Errorf("wrapped: %w", &myError{"EOF"}), io.EOF},
+			{true, false, false, fmt.Errorf("wrapped[]: %w %w", io.EOF, &myError{"EOF"}), io.EOF},
+			{true, false, false, fmt.Errorf("wrapped[]: %w %w", &myError{"EOF"}, io.EOF), io.EOF},
+			{true, false, false, fmt.Errorf("wrapped[]: %w %w", &myError{"EOF"}, io.EOF), &myError{"EOF"}},
+			{false, false, false, fmt.Errorf("wrapped[]: %w %w", io.EOF, &myError{"EOF"}), &myError{"EOF"}},
 			{true, false, false, fmt.Errorf("wrapped2: %w", fmt.Errorf("wrapped: %w", io.EOF)), io.EOF},
 			{true, false, false, fmt.Errorf("wrapped2: %w", pkgerrors.Wrap(io.EOF, "wrapped")), io.EOF},
 			{true, false, false, pkgerrors.Wrap(fmt.Errorf("wrapped: %w", io.EOF), "wrapped2"), io.EOF},
@@ -1674,6 +1686,7 @@ func TestCheckers(t *testing.T) {
 		for _, v := range cases {
 			t.Run("", func(tt *testing.T) {
 				t := check.T(tt)
+				todo := t.TODO()
 				if v.err {
 					t.Err(v.actual, v.expected)
 					todo.NotErr(v.actual, v.expected)
